@@ -15,9 +15,9 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
- 
-#ifndef DIALOG_PARTITION_COPY
-#define DIALOG_PARTITION_COPY
+
+#ifndef GPARTED_DIALOG_PARTITION_COPY_H
+#define GPARTED_DIALOG_PARTITION_COPY_H
 
 #include "../include/Dialog_Base_Partition.h"
 
@@ -37,4 +37,4 @@ private:
 
 }//GParted
 
-#endif //DIALOG_PARTITION_COPY
+#endif /* GPARTED_DIALOG_PARTITION_COPY_H */
