@@ -15,8 +15,8 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef OPERATIONDELETE
-#define OPERATIONDELETE
+#ifndef GPARTED_OPERATIONDELETE_H
+#define GPARTED_OPERATIONDELETE_H
 
 #include "../include/Operation.h"
 
@@ -37,4 +37,4 @@ private:
 
 } //GParted
 
-#endif //OPERATIONDELETE
+#endif /* GPARTED_OPERATIONDELETE_H */
