@@ -58,36 +58,38 @@ const Glib::ustring UUID_RANDOM_NTFS_HALF = _("(Half new UUID - will be randomly
 
 enum FILESYSTEM
 {
-	FS_UNALLOCATED	= 0,
-	FS_UNKNOWN	= 1,
-	FS_UNFORMATTED	= 2,
-	FS_CLEARED	= 3,  //Clear existing file system signatures
-	FS_EXTENDED	= 4,
+	FS_UNALLOCATED     = 0,
+	FS_UNKNOWN         = 1,
+	FS_UNFORMATTED     = 2,
+	FS_CLEARED         = 3,  //Clear existing file system signatures
+	FS_EXTENDED        = 4,
 
-	FS_BTRFS	= 5,
-	FS_EXFAT	= 6, /* Also known as fat64 */
-	FS_EXT2		= 7,
-	FS_EXT3		= 8,
-	FS_EXT4		= 9,
-	FS_F2FS		= 10,
-	FS_FAT16	= 11,
-	FS_FAT32	= 12,
-	FS_HFS		= 13,
-	FS_HFSPLUS	= 14,
-	FS_JFS		= 15,
-	FS_LINUX_SWAP	= 16,
-	FS_LVM2_PV	= 17,
-	FS_NILFS2	= 18,
-	FS_NTFS		= 19,
-	FS_REISER4	= 20,
-	FS_REISERFS	= 21,
-	FS_UFS		= 22,
-	FS_XFS		= 23,
+	FS_BTRFS           = 5,
+	FS_EXFAT           = 6, /* Also known as fat64 */
+	FS_EXT2            = 7,
+	FS_EXT3            = 8,
+	FS_EXT4            = 9,
+	FS_F2FS            = 10,
+	FS_FAT16           = 11,
+	FS_FAT32           = 12,
+	FS_HFS             = 13,
+	FS_HFSPLUS         = 14,
+	FS_JFS             = 15,
+	FS_LINUX_SWAP      = 16,
+	FS_LVM2_PV         = 17,
+	FS_NILFS2          = 18,
+	FS_NTFS            = 19,
+	FS_REISER4         = 20,
+	FS_REISERFS        = 21,
+	FS_UFS             = 22,
+	FS_XFS             = 23,
 
-	FS_USED		= 24,
-	FS_UNUSED	= 25,
+	FS_USED            = 24,
+	FS_UNUSED          = 25,
 
-	FS_LUKS		= 26
+	FS_LUKS            = 26,
+	FS_LINUX_SWRAID    = 27,
+	FS_LINUX_SWSUSPEND = 28
 } ;
 
 enum SIZE_UNIT
@@ -136,6 +138,8 @@ struct FS
 	Support copy ;
 	Support remove ;
 	Support online_read ;  //Can and how to read sector usage while active
+	Support online_grow ;
+	Support online_shrink ;
 
 	Byte_Value MIN ; 
 	Byte_Value MAX ;
@@ -143,7 +147,8 @@ struct FS
 	FS()
 	{
 		read = read_label = write_label = read_uuid = write_uuid = create = create_with_label =
-		grow = shrink = move = check = copy = remove = online_read = NONE ;
+		grow = shrink = move = check = copy = remove = online_read =
+		online_grow = online_shrink = NONE ;
 		MIN = MAX = 0 ;
 	} 
 } ;
@@ -155,8 +160,6 @@ public:
 	static Sector round( double double_value ) ;
 	static Gtk::Label * mk_label( const Glib::ustring & text,
 				      bool use_markup = true,
-			      	      Gtk::AlignmentEnum x_align = Gtk::ALIGN_LEFT,
-			      	      Gtk::AlignmentEnum y_align = Gtk::ALIGN_CENTER,
 				      bool wrap = false,
 				      bool selectable = false,
 				      const Glib::ustring & text_color = "black" ) ;
@@ -168,6 +171,7 @@ public:
 	static Glib::ustring get_filesystem_software( FILESYSTEM filesystem ) ;
 	static bool kernel_supports_fs( const Glib::ustring & fs ) ;
 	static bool kernel_version_at_least( int major_ver, int minor_ver, int patch_ver ) ;
+	static bool swraid_member_is_active( const Glib::ustring & path ) ;
 	static Glib::ustring format_size( Sector sectors, Byte_Value sector_size ) ;
 	static Glib::ustring format_time( std::time_t seconds ) ;
 	static double sector_to_unit( Sector sectors, Byte_Value sector_size, SIZE_UNIT size_unit ) ;
@@ -179,9 +183,6 @@ public:
 	static Glib::ustring regexp_label( const Glib::ustring & text
 	                                 , const Glib::ustring & pattern
 	                                 ) ;
-	static Glib::ustring create_mtoolsrc_file( char file_name[],
-                    const char drive_letter, const Glib::ustring & device_path ) ;
-	static Glib::ustring delete_mtoolsrc_file( const char file_name[] ) ;
 	static Glib::ustring trim( const Glib::ustring & src, const Glib::ustring & c = " \t\r\n" ) ;
 	static Glib::ustring get_lang() ;
 	static void tokenize( const Glib::ustring& str,
@@ -194,7 +195,7 @@ public:
 	static Glib::ustring generate_uuid(void);
 	static int get_mounted_filesystem_usage( const Glib::ustring & mountpoint,
 	                                         Byte_Value & fs_size, Byte_Value & fs_free,
-	                                         Glib::ustring error_message ) ;
+	                                         Glib::ustring & error_message ) ;
 	static Byte_Value floor_size( Byte_Value value, Byte_Value rounding_size ) ;
 	static Byte_Value ceil_size( Byte_Value value, Byte_Value rounding_size ) ;
 
