@@ -15,9 +15,9 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
- 
-#ifndef WIN_GPARTED
-#define WIN_GPARTED
+
+#ifndef GPARTED_WIN_GPARTED_H
+#define GPARTED_WIN_GPARTED_H
 
 #include "../include/Device.h"
 #include "../include/DrawingAreaVisualDisk.h"
@@ -65,6 +65,7 @@ private:
 	void Refresh_Visual();
 	bool Quit_Check_Operations();
 	void set_valid_operations() ;
+	void show_operationslist() ;
 	
 	//convenience functions
 	void toggle_item( bool state, int menu_item, int toolbar_item = -1 )
@@ -261,4 +262,4 @@ private:
 
 } //GParted
 
-#endif //WIN_GPARTED
+#endif /* GPARTED_WIN_GPARTED_H */
