@@ -15,10 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
- 
- 
-#ifndef DEFINE_HFSPLUS
-#define DEFINE_HFSPLUS
+
+
+#ifndef GPARTED_HFSPLUS_H
+#define GPARTED_HFSPLUS_H
 
 #include "../include/FileSystem.h"
 
@@ -36,4 +36,4 @@ public:
 
 } //GParted
 
-#endif //HFSPLUS
+#endif /* GPARTED_HFSPLUS_H */
