@@ -15,10 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
- 
- 
-#ifndef DEFINE_REISERFS
-#define DEFINE_REISERFS
+
+
+#ifndef GPARTED_REISERFS_H
+#define GPARTED_REISERFS_H
 
 #include "../include/FileSystem.h"
 
@@ -41,4 +41,4 @@ public:
 
 } //GParted
 
-#endif //REISERFS
+#endif /* GPARTED_REISERFS_H */
