@@ -58,21 +58,30 @@ Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition )
 
 		frame ->set_label_widget( *hbox ) ;
 
-		//FIXME: for more clarity we should add a listview here with alternating rowcolors..
-		//that way it's easier to tell messages apart..
+		//Merge all messages for display so that they can be selected together.
+		//  Use a blank line between individual messages so that each message can be
+		//  distinguished. Therefore each message should have been formatted as one
+		//  or more non-blank lines, with an optional trailing new line.  This is
+		//  true of GParted internal messages and probably all external messages and
+		//  errors from libparted and executed commands too.
+		Glib::ustring all_messages ;
+		for ( unsigned int t = 0; t < partition .messages .size(); t ++ )
 		{
-			Gtk::VBox* vbox(manage(new Gtk::VBox(false,4)));
-			vbox->set_border_width(5);
+			if ( all_messages .size() > 0 )
+				all_messages += "\n\n" ;
 
-			for (unsigned int t = 0; t < partition.messages.size(); ++t)
-				vbox->pack_start(*Utils::mk_label("<i>" + partition .messages[t] + "</i>",
-								true,
-								Gtk::ALIGN_LEFT,
-								Gtk::ALIGN_CENTER,
-								true),
-						Gtk::PACK_SHRINK);
-			frame->add(*vbox);
+			Glib::ustring::size_type take = partition .messages[ t ] .size() ;
+			if ( take > 0 )
+			{
+				if ( partition .messages[ t ][ take-1 ] == '\n' )
+					take -- ;  //Skip optional trailing new line
+				all_messages += "<i>" + partition .messages[ t ] .substr( 0, take ) + "</i>" ;
+			}
 		}
+		Gtk::VBox *vbox( manage( new Gtk::VBox() ) ) ;
+		vbox ->set_border_width( 5 ) ;
+		vbox ->pack_start( *Utils::mk_label( all_messages, true, true, true ), Gtk::PACK_SHRINK ) ;
+		frame ->add( *vbox ) ;
 
 		this ->get_vbox() ->pack_start( *frame, Gtk::PACK_SHRINK ) ;
 	}
@@ -186,7 +195,7 @@ void Dialog_Partition_Info::Display_Info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( Utils::get_filesystem_string( partition .filesystem ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+	table ->attach( * Utils::mk_label( Utils::get_filesystem_string( partition .filesystem ), true, false, true ),
 			1, 2,
 			top++, bottom++,
 			Gtk::FILL ) ;
@@ -196,7 +205,7 @@ void Dialog_Partition_Info::Display_Info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL) ;
-	table ->attach( * Utils::mk_label( Utils::format_size( ptn_sectors, partition .sector_size ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+	table ->attach( * Utils::mk_label( Utils::format_size( ptn_sectors, partition .sector_size ), true, false, true ),
 			1, 2,
 			top++, bottom++,
 			Gtk::FILL ) ;
@@ -212,7 +221,7 @@ void Dialog_Partition_Info::Display_Info()
 				0, 1,
 				top, bottom,
 				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_used(), partition .sector_size ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_used(), partition .sector_size ), true, false, true ),
 				1, 2,
 				top, bottom,
 				Gtk::FILL ) ;
@@ -226,7 +235,7 @@ void Dialog_Partition_Info::Display_Info()
 				0, 1,
 				top, bottom,
 				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_unused(), partition .sector_size ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_unused(), partition .sector_size ), true, false, true ),
 				1, 2,
 				top, bottom,
 				Gtk::FILL ) ;
@@ -243,7 +252,7 @@ void Dialog_Partition_Info::Display_Info()
 					0, 1,
 					top, bottom,
 					Gtk::FILL ) ;
-			table ->attach( * Utils::mk_label( Utils::format_size( sectors_unallocated, partition .sector_size ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+			table ->attach( * Utils::mk_label( Utils::format_size( sectors_unallocated, partition .sector_size ), true, false, true ),
 					1, 2,
 					top, bottom,
 					Gtk::FILL ) ;
@@ -265,7 +274,7 @@ void Dialog_Partition_Info::Display_Info()
 				0, 1,
 				top, bottom,
 				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Glib::build_path( ", ", partition .flags ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+		table ->attach( * Utils::mk_label( Glib::build_path( ", ", partition .flags ), true, false, true ),
 				1, 2, 
 				top++, bottom++,
 				Gtk::FILL ) ;
@@ -277,14 +286,11 @@ void Dialog_Partition_Info::Display_Info()
 	if ( partition .type != GParted::TYPE_UNALLOCATED && partition .status != GParted::STAT_NEW )
 	{
 		//path
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Path:") ) + "</b>",
-						   true,
-						   Gtk::ALIGN_LEFT,
-						   Gtk::ALIGN_TOP ),
+		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Path:") ) + "</b>" ),
 				0, 1,
 				top, bottom,
 				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Glib::build_path( "\n", partition .get_paths() ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+		table ->attach( * Utils::mk_label( Glib::build_path( "\n", partition .get_paths() ), true, false, true ),
 				1, 2,
 				top++, bottom++,
 				Gtk::FILL ) ;
@@ -305,11 +311,13 @@ void Dialog_Partition_Info::Display_Info()
 				 */
 				str_temp =  _("Busy (At least one logical partition is mounted)") ;
 			}
-			else if ( partition .filesystem == FS_LINUX_SWAP )
+			else if (    partition .filesystem == FS_LINUX_SWAP
+			          || partition .filesystem == FS_LINUX_SWRAID
+			        )
 			{
 				/* TO TRANSLATORS:  Active
-				 * means that this linux swap partition is enabled and being used by
-				 * the operating system.
+				 * means that this linux swap or linux software raid partition
+				 * is enabled and being used by the operating system.
 				 */
 				str_temp = _("Active") ;
 			}
@@ -337,11 +345,13 @@ void Dialog_Partition_Info::Display_Info()
 			 */
 			str_temp = _("Not busy (There are no mounted logical partitions)") ;
 		}
-		else if ( partition.filesystem == GParted::FS_LINUX_SWAP )
+		else if (    partition .filesystem == FS_LINUX_SWAP
+		          || partition .filesystem == FS_LINUX_SWRAID
+		        )
 		{
 			/* TO TRANSLATORS:  Not active
-			 *  means that this linux swap partition is not enabled and is not
-			 *  in use by the operating system.
+			 *  means that this linux swap or linux software raid partition
+			 *  is not enabled and is not in use by the operating system.
 			 */
 			str_temp = _("Not active") ;
 		}
@@ -377,7 +387,7 @@ void Dialog_Partition_Info::Display_Info()
 			str_temp = _("Not mounted") ;
 		}
 
-		table ->attach( * Utils::mk_label( str_temp, true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ), 1, 2, top++, bottom++, Gtk::FILL ) ;
+		table ->attach( * Utils::mk_label( str_temp, true, false, true ), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	}
 
 	//label
@@ -387,7 +397,7 @@ void Dialog_Partition_Info::Display_Info()
 				0, 1,
 				top, bottom,
 				Gtk::FILL) ;
-		table ->attach( * Utils::mk_label( partition .get_label(), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+		table ->attach( * Utils::mk_label( partition .get_label(), true, false, true ),
 				1, 2,
 				top++, bottom++,
 				Gtk::FILL) ;
@@ -400,7 +410,7 @@ void Dialog_Partition_Info::Display_Info()
 				0, 1,
 				top, bottom,
 				Gtk::FILL) ;
-		table ->attach( * Utils::mk_label( partition .uuid, true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+		table ->attach( * Utils::mk_label( partition .uuid, true, false, true ),
 				1, 2,
 				top++, bottom++,
 				Gtk::FILL) ;
@@ -414,7 +424,7 @@ void Dialog_Partition_Info::Display_Info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( Utils::num_to_str( partition .sector_start ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+	table ->attach( * Utils::mk_label( Utils::num_to_str( partition .sector_start ), true, false, true ),
 			1, 2,
 			top++, bottom++,
 			Gtk::FILL ) ;
@@ -424,7 +434,7 @@ void Dialog_Partition_Info::Display_Info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( Utils::num_to_str( partition.sector_end ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+	table ->attach( * Utils::mk_label( Utils::num_to_str( partition.sector_end ), true, false, true ),
 			1, 2,
 			top++, bottom++,
 			Gtk::FILL ) ; 
@@ -434,7 +444,7 @@ void Dialog_Partition_Info::Display_Info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( Utils::num_to_str( ptn_sectors ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+	table ->attach( * Utils::mk_label( Utils::num_to_str( ptn_sectors ), true, false, true ),
 			1, 2,
 			top++, bottom++,
 			Gtk::FILL ) ;
@@ -454,7 +464,7 @@ void Dialog_Partition_Info::Display_Info()
 		//Volume Group
 		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Volume Group:") ) + "</b>"),
 		                0, 1, top, bottom, Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( vgname, true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+		table ->attach( * Utils::mk_label( vgname, true, false, true ),
 		                1, 2, top++, bottom++, Gtk::FILL ) ;
 
 		//Members
@@ -469,12 +479,12 @@ void Dialog_Partition_Info::Display_Info()
 			table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL ) ;
 		else
 		{
-			table ->attach( * Utils::mk_label( members [0], true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+			table ->attach( * Utils::mk_label( members [0], true, false, true ),
 			                1, 2, top++, bottom++, Gtk::FILL ) ;
 			for ( unsigned int i = 1 ; i < members .size() ; i ++ )
 			{
 				table ->attach( * Utils::mk_label( "" ), 0, 1, top, bottom, Gtk::FILL) ;
-				table ->attach( * Utils::mk_label( members [i], true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+				table ->attach( * Utils::mk_label( members [i], true, false, true ),
 				                1, 2, top++, bottom++, Gtk::FILL ) ;
 			}
 		}
@@ -483,10 +493,10 @@ void Dialog_Partition_Info::Display_Info()
 
 Dialog_Partition_Info::~Dialog_Partition_Info()
 {
-	this ->get_colormap() ->free_colors( color_used, 1 ) ;
-	this ->get_colormap() ->free_colors( color_unused, 1 ) ;
-	this ->get_colormap() ->free_colors( color_text, 1 ) ;
-	this ->get_colormap() ->free_colors( color_partition, 1 ) ;
+	this ->get_colormap() ->free_color( color_used ) ;
+	this ->get_colormap() ->free_color( color_unused ) ;
+	this ->get_colormap() ->free_color( color_text ) ;
+	this ->get_colormap() ->free_color( color_partition ) ;
 }
 
 } //GParted
