@@ -47,13 +47,15 @@ void Dialog_Partition_New::Set_Data( const Partition & partition,
 	//  the order of items in the file system menu, built by Build_Filesystems_Menu().
 	this ->FILESYSTEMS = FILESYSTEMS ;
 
-	//... remove all non-valid file systems
+	//... remove all non-file systems or file systems only recognised but not otherwise supported
 	std::vector< FS >::iterator f ;
 	for ( f = this->FILESYSTEMS .begin(); f != this->FILESYSTEMS .end(); f++ )
 	{
 		if (   f ->filesystem == FS_UNKNOWN
 		    || f ->filesystem == FS_CLEARED
 		    || f ->filesystem == FS_LUKS
+		    || f ->filesystem == FS_LINUX_SWRAID
+		    || f ->filesystem == FS_LINUX_SWSUSPEND
 		   )
 			//Compensate for subsequent 'f++' ...
 			f = this ->FILESYSTEMS .erase( f ) - 1 ;
@@ -343,9 +345,12 @@ void Dialog_Partition_New::Build_Filesystems_Menu( bool only_unformatted )
 		menu_filesystem .items() .back() .set_sensitive(
 			! only_unformatted && FILESYSTEMS[ t ] .create &&
 			this ->selected_partition .get_byte_length() >= FILESYSTEMS[ t ] .MIN ) ;
-		//use ext2 as default filesystem
-		if ( Utils::get_filesystem_string( FILESYSTEMS[ t ] .filesystem ) == "ext2" &&
-			menu_filesystem .items() .back() .sensitive() )
+		//use ext4/3/2 as first/second/third choice default file system
+		//(Depends on ordering in FILESYSTEMS for preference)
+		if ( ( FILESYSTEMS[ t ] .filesystem == FS_EXT2 ||
+		       FILESYSTEMS[ t ] .filesystem == FS_EXT3 ||
+		       FILESYSTEMS[ t ] .filesystem == FS_EXT4    ) &&
+		     menu_filesystem .items() .back() .sensitive()     )
 		{
 			first_creatable_fs=menu_filesystem .items() .size() - 1;
 			set_first=true;
@@ -357,7 +362,7 @@ void Dialog_Partition_New::Build_Filesystems_Menu( bool only_unformatted )
 	
 	if(!set_first)
 	{
-		//find and set first enabled file system
+		//find and set first enabled file system as last choice default
 		for ( unsigned int t = 0 ; t < menu_filesystem .items() .size() ; t++ )
 			if ( menu_filesystem .items()[ t ] .sensitive() )
 			{
