@@ -62,7 +62,9 @@ void FileSystem::store_exit_status( GPid pid, int status )
 	Glib::spawn_close_pid( pid );
 }
 
-static void relay_update( OperationDetail *operationdetail, Glib::ustring *str )
+//Callback passing the latest partial output from the external command
+//  to operation detail for updating in the UI
+static void update_command_output( OperationDetail *operationdetail, Glib::ustring *str )
 {
 	operationdetail->set_description( *str, FONT_ITALIC );
 }
@@ -111,19 +113,19 @@ int FileSystem::execute_command( const Glib::ustring & command, OperationDetail
 	pipecount = 2;
 	PipeCapture outputcapture( out, output );
 	PipeCapture errorcapture( err, error );
-	outputcapture.eof.connect( sigc::mem_fun( *this, &FileSystem::execute_command_eof ) );
-	errorcapture.eof.connect( sigc::mem_fun( *this, &FileSystem::execute_command_eof ) );
+	outputcapture.signal_eof.connect( sigc::mem_fun( *this, &FileSystem::execute_command_eof ) );
+	errorcapture.signal_eof.connect( sigc::mem_fun( *this, &FileSystem::execute_command_eof ) );
 	operationdetail.get_last_child().add_child(
 		OperationDetail( output, STATUS_NONE, FONT_ITALIC ) );
 	operationdetail.get_last_child().add_child(
 		OperationDetail( error, STATUS_NONE, FONT_ITALIC ) );
 	std::vector<OperationDetail> &children = operationdetail.get_last_child().get_childs();
-	outputcapture.update.connect( sigc::bind( sigc::ptr_fun( relay_update ),
-						  &(children[children.size() - 2]),
-						  &output ) );
-	errorcapture.update.connect( sigc::bind( sigc::ptr_fun( relay_update ),
-						 &(children[children.size() - 1]),
-						 &error ) );
+	outputcapture.signal_update.connect( sigc::bind( sigc::ptr_fun( update_command_output ),
+	                                                 &(children[children.size() - 2]),
+	                                                 &output ) );
+	errorcapture.signal_update.connect( sigc::bind( sigc::ptr_fun( update_command_output ),
+	                                                &(children[children.size() - 1]),
+	                                                &error ) );
 	outputcapture.connect_signal();
 	errorcapture.connect_signal();
 
