@@ -45,14 +45,14 @@ Sector Utils::round( double double_value )
 
 Gtk::Label * Utils::mk_label( const Glib::ustring & text,
 			      bool use_markup,
-			      Gtk::AlignmentEnum x_align,
-			      Gtk::AlignmentEnum y_align,
 			      bool wrap,
 			      bool selectable,
 			      const Glib::ustring & text_color )
 {
-
-	Gtk::Label * label = manage( new Gtk::Label( text, x_align, y_align ) ) ;
+	//xalign 0.0 == Gtk::ALIGN_LEFT  (gtkmm <= 2.22)
+	//           == Gtk::ALIGN_START (gtkmm >= 2.24)
+	//yalign 0.5 == Gtk::ALIGN_CENTER
+	Gtk::Label * label = manage( new Gtk::Label( text, 0.0, 0.5 ) ) ;
 
 	label ->set_use_markup( use_markup ) ;
 	label ->set_line_wrap( wrap ) ;
@@ -106,6 +106,8 @@ Glib::ustring Utils::get_color( FILESYSTEM filesystem )
 		case FS_UNUSED		: return "#FFFFFF" ;	//white
 		case FS_LVM2_PV		: return "#CC9966" ;	// ~ medium brown
 		case FS_LUKS		: return "#625B81" ;	//purple dark
+		case FS_LINUX_SWRAID   	: return "#5A4733" ;	// ~ dark brown
+		case FS_LINUX_SWSUSPEND	: return "#884631" ;	//red dark
 
 		default				: return "#000000" ;
 	}
@@ -233,6 +235,8 @@ Glib::ustring Utils::get_filesystem_string( FILESYSTEM filesystem )
 		case FS_UNUSED		: return _("unused") ;
 		case FS_LVM2_PV		: return "lvm2 pv" ;
 		case FS_LUKS		: return "crypt-luks" ;
+		case FS_LINUX_SWRAID	: return "linux-raid" ;
+		case FS_LINUX_SWSUSPEND	: return "linux-suspend" ;
 
 		default			: return "" ;
 	}
@@ -320,6 +324,39 @@ bool Utils::kernel_version_at_least( int major_ver, int minor_ver, int patch_ver
 	return result ;
 }
 
+//Report whether the device is an active member of a Linux Software RAID array
+bool Utils::swraid_member_is_active( const Glib::ustring & path )
+{
+	//Read /proc/mdstat and look for the device name on an active RAID array
+	//  line.   Example line: "md1 : active raid1 sda1[2] sdb1[3]"
+	//                                           ^^^^^^
+	//                                           needle
+	//  Strip "/dev/" prefix and search for device name with surrounding
+	//  " " and "[" to avoid substring matches.
+	if ( path .substr( 0, 5 ) != "/dev/" )
+		return false ;
+
+	bool member_active = false ;
+	Glib::ustring needle = " " + path .substr( 5 ) + "[" ;
+	std::string line ;
+	std::ifstream input( "/proc/mdstat" ) ;
+	if ( input )
+	{
+		while ( getline( input, line ) )
+		{
+			if (    line .find( " : active " ) != std::string::npos
+			     && line .find( needle ) != std::string::npos       )
+			{
+				member_active = true ;
+				break ;
+			}
+		}
+		input .close() ;
+	}
+
+	return member_active ;
+}
+
 Glib::ustring Utils::format_size( Sector sectors, Byte_Value sector_size )
 {
 	std::stringstream ss ;
@@ -653,7 +690,7 @@ Glib::ustring Utils::generate_uuid(void)
 //  and free space, both in bytes.
 int Utils::get_mounted_filesystem_usage( const Glib::ustring & mountpoint,
                                          Byte_Value & fs_size, Byte_Value & fs_free,
-                                         Glib::ustring error_message )
+                                         Glib::ustring & error_message )
 {
 	struct statvfs sfs ;
 	int ret ;
@@ -664,7 +701,7 @@ int Utils::get_mounted_filesystem_usage( const Glib::ustring & mountpoint,
 		fs_free = static_cast<Byte_Value>( sfs .f_bfree ) * sfs .f_bsize ;
 	}
 	else
-		error_message = "statvfs (" + mountpoint + "): " + Glib::strerror( errno ) ;
+		error_message = "statvfs(\"" + mountpoint + "\"): " + Glib::strerror( errno ) ;
 
 	return ret ;
 }
@@ -687,11 +724,11 @@ Byte_Value Utils::ceil_size( Byte_Value value, Byte_Value rounding_size )
 bool Utils::get_kernel_version( int & major_ver, int & minor_ver, int & patch_ver )
 {
 	static bool read_file = false ;
-	static int read_major_ver = -1 ;
-	static int read_minor_ver = -1 ;
-	static int read_patch_ver = -1 ;
+	static int read_major_ver = 0 ;
+	static int read_minor_ver = 0 ;
+	static int read_patch_ver = 0 ;
+	static bool success = false ;
 
-	bool success = false ;
 	if ( ! read_file )
 	{
 		std::ifstream input( "/proc/version" ) ;
@@ -699,18 +736,18 @@ bool Utils::get_kernel_version( int & major_ver, int & minor_ver, int & patch_ve
 		if ( input )
 		{
 			getline( input, line ) ;
-			sscanf( line .c_str(), "Linux version %d.%d.%d",
-			        &read_major_ver, &read_minor_ver, &read_patch_ver ) ;
+			int assigned = sscanf( line .c_str(), "Linux version %d.%d.%d",
+			                       &read_major_ver, &read_minor_ver, &read_patch_ver ) ;
+			success = ( assigned >= 2 ) ;  //At least 2 kernel version components read
 			input .close() ;
 		}
 		read_file = true ;
 	}
-	if ( read_major_ver > -1 && read_minor_ver > -1 && read_patch_ver > -1 )
+	if ( success )
 	{
 		major_ver = read_major_ver ;
 		minor_ver = read_minor_ver ;
 		patch_ver = read_patch_ver ;
-		success = true ;
 	}
 	return success ;
 }
