@@ -416,10 +416,12 @@ Gtk::Menu * Win_GParted::create_format_menu()
 
 	for ( unsigned int t = 0 ; t < fss .size() ; t++ )
 	{
-		//Skip unknown, cleared and luks because these are not file systems
+		//Skip non-file systems or file systems only recognised but not otherwise supported
 		if (    fss[ t ] .filesystem == FS_UNKNOWN
 		     || fss[ t ] .filesystem == FS_CLEARED
 		     || fss[ t ] .filesystem == FS_LUKS
+		     || fss[ t ] .filesystem == FS_LINUX_SWRAID
+		     || fss[ t ] .filesystem == FS_LINUX_SWSUSPEND
 		   )
 			continue ;
 
@@ -470,7 +472,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//size
@@ -478,18 +480,15 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//path
-	table ->attach( * Utils::mk_label( " <b>" + static_cast<Glib::ustring>( _("Path:") ) + "</b>",
-					   true,
-					   Gtk::ALIGN_LEFT,
-					   Gtk::ALIGN_TOP ),
+	table ->attach( * Utils::mk_label( " <b>" + static_cast<Glib::ustring>( _("Path:") ) + "</b>" ),
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	vbox_info .pack_start( *table, Gtk::PACK_SHRINK );
@@ -507,7 +506,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL );
-	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//heads
@@ -515,7 +514,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//sectors/track
@@ -523,7 +522,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL );
 	
 	//cylinders
@@ -531,7 +530,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//total sectors
@@ -539,7 +538,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL );
-	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 
 	//sector size
@@ -547,7 +546,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL );
-	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 
 	vbox_info .pack_start( *table, Gtk::PACK_SHRINK );
@@ -594,12 +593,10 @@ void Win_GParted::refresh_combo_devices()
 	
 		//devices submenu....
 		hbox = manage( new Gtk::HBox() ) ;
-		hbox ->pack_start( * Utils::mk_label( devices[ i ] .get_path() ), Gtk::PACK_SHRINK ) ;
-		hbox ->pack_start( * Utils::mk_label( "   (" + Utils::format_size( devices[ i ] .length, devices[ i ] .sector_size ) + ")",
-					              true,
-						      Gtk::ALIGN_RIGHT ),
-				   Gtk::PACK_EXPAND_WIDGET ) ;
-		
+		hbox ->pack_start( * Utils::mk_label( devices[ i ] .get_path() ), Gtk::PACK_EXPAND_WIDGET ) ;
+		hbox ->pack_start( * Utils::mk_label( "   (" + Utils::format_size( devices[ i ] .length, devices[ i ] .sector_size ) + ")" ),
+		                   Gtk::PACK_SHRINK ) ;
+
 		menu ->items() .push_back( * manage( new Gtk::RadioMenuItem( radio_group ) ) ) ;
 		menu ->items() .back() .add( *hbox ) ;
 		menu ->items() .back() .signal_activate() .connect( 
@@ -946,7 +943,10 @@ void Win_GParted::set_valid_operations()
 	//no partition selected...	
 	if ( ! selected_partition .get_paths() .size() )
 		return ;
-	
+
+	//get filesystem capabilities
+	fs = gparted_core .get_fs( selected_partition .filesystem ) ;
+
 	//if there's something, there's some info ;)
 	allow_info( true ) ;
 	
@@ -970,10 +970,11 @@ void Win_GParted::set_valid_operations()
 			                                           : CTEXT_ACTIVATE_FILESYSTEM )
 			                                          ) ;
 
-	//Only permit mount/unmount, swapon/swapoff, ... if action is available
+	//Only permit mount/unmount, swapon/swapoff, activate/deactivate if action is available
 	if (    selected_partition .status == GParted::STAT_REAL
 	     && selected_partition .type != GParted::TYPE_EXTENDED
 	     && selected_partition .filesystem != GParted::FS_LVM2_PV
+	     && selected_partition .filesystem != FS_LINUX_SWRAID
 	     && (    selected_partition .busy
 	          || selected_partition .get_mountpoints() .size() /* Have mount point(s) */
 	          || selected_partition .filesystem == GParted::FS_LINUX_SWAP
@@ -996,7 +997,16 @@ void Win_GParted::set_valid_operations()
 	   )
 		allow_toggle_busy_state( true ) ;
 
-	//only unmount/swapoff/VG deactivate/... is allowed if busy
+#ifdef ENABLE_ONLINE_RESIZE
+	//Find out if online resizing is possible
+	if ( selected_partition .busy )
+	{
+		if ( ( fs .online_grow || fs .online_shrink ) && ! devices[ current_device ] .readonly )
+			allow_resize( true ) ;
+	}
+#endif
+
+	//only unmount/swapoff/VG deactivate or online actions allowed if busy
 	if ( selected_partition .busy )
 		return ;
 
@@ -1075,8 +1085,6 @@ void Win_GParted::set_valid_operations()
 	//PRIMARY and LOGICAL
 	if (  selected_partition .type == GParted::TYPE_PRIMARY || selected_partition .type == GParted::TYPE_LOGICAL )
 	{
-		fs = gparted_core .get_fs( selected_partition .filesystem ) ;
-		
 		allow_delete( true ) ;
 		allow_format( true ) ;
 		
@@ -2768,7 +2776,7 @@ bool Win_GParted::remove_non_empty_lvm2_pv_dialog( const OperationType optype )
 	//Volume Group
 	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( vgname_label ) + "</b>" ),
 	                0, 1, top, bottom, Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( vgname, true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+	table ->attach( * Utils::mk_label( vgname, true, false, true ),
 	                1, 2, top++, bottom++, Gtk::FILL ) ;
 
 	//Members
@@ -2779,12 +2787,12 @@ bool Win_GParted::remove_non_empty_lvm2_pv_dialog( const OperationType optype )
 		table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	else
 	{
-		table ->attach( * Utils::mk_label( members [0], true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+		table ->attach( * Utils::mk_label( members [0], true, false, true ),
 				1, 2, top++, bottom++, Gtk::FILL ) ;
 		for ( unsigned int i = 1 ; i < members .size() ; i ++ )
 		{
 			table ->attach( * Utils::mk_label( "" ), 0, 1, top, bottom, Gtk::FILL ) ;
-			table ->attach( * Utils::mk_label( members [i], true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+			table ->attach( * Utils::mk_label( members [i], true, false, true ),
 					1, 2, top++, bottom++, Gtk::FILL ) ;
 		}
 
