@@ -78,6 +78,7 @@ FS btrfs::get_filesystem_support()
 		{
 			fs .read = GParted::FS::EXTERNAL ;
 			fs .read_label = FS::EXTERNAL ;
+			fs .read_uuid = FS::EXTERNAL ;
 		}
 
 		//Resizing of btrfs requires btrfsctl, mount, umount
@@ -102,6 +103,13 @@ FS btrfs::get_filesystem_support()
 	}
 
 	fs .online_read = FS::GPARTED ;
+#ifdef ENABLE_ONLINE_RESIZE
+	if ( Utils::kernel_version_at_least( 3, 6, 0 ) )
+	{
+		fs .online_grow = fs .grow ;
+		fs .online_shrink = fs .shrink ;
+	}
+#endif
 
 	fs .MIN = 256 * MEBIBYTE ;
 
@@ -173,12 +181,17 @@ bool btrfs::resize( const Partition & partition_new, OperationDetail & operation
 {
 	bool success = true ;
 
-	Glib::ustring mount_point = mk_temp_dir( "", operationdetail ) ;
-	if ( mount_point .empty() )
-		return false ;
-
-	success &= ! execute_command( "mount -v -t btrfs " + partition_new .get_path() + " " + mount_point,
-				      operationdetail, true ) ;
+	Glib::ustring mount_point ;
+	if ( ! partition_new .busy )
+	{
+		mount_point = mk_temp_dir( "", operationdetail ) ;
+		if ( mount_point .empty() )
+			return false ;
+		success &= ! execute_command( "mount -v -t btrfs " + partition_new .get_path() + " " + mount_point,
+		                              operationdetail, true ) ;
+	}
+	else
+		mount_point = partition_new .get_mountpoint() ;
 
 	if ( success )
 	{
@@ -218,10 +231,12 @@ bool btrfs::resize( const Partition & partition_new, OperationDetail & operation
 		operationdetail .get_last_child() .set_status( resize_succeeded ? STATUS_SUCCES : STATUS_ERROR ) ;
 		success &= resize_succeeded ;
 
-		success &= ! execute_command( "umount -v " + mount_point, operationdetail, true ) ;
+		if ( ! partition_new .busy )
+			success &= ! execute_command( "umount -v " + mount_point, operationdetail, true ) ;
 	}
 
-	rm_temp_dir( mount_point, operationdetail ) ;
+	if ( ! partition_new .busy )
+		rm_temp_dir( mount_point, operationdetail ) ;
 
 	return success ;
 }
