@@ -28,7 +28,10 @@ FS f2fs::get_filesystem_support()
 	fs .filesystem = FS_F2FS ;
 
 	if ( ! Glib::find_program_in_path( "mkfs.f2fs" ) .empty() )
+	{
 		fs .create = GParted::FS::EXTERNAL ;
+		fs .create_with_label = GParted::FS::EXTERNAL ;
+	}
 
 	fs .copy = FS::GPARTED ;
 	fs .move = FS::GPARTED ;
