@@ -61,19 +61,36 @@ const Glib::ustring fat16::get_custom_text( CUSTOM_TEXT ttype, int index )
 FS fat16::get_filesystem_support()
 {
 	FS fs ;
-	fs .filesystem = GParted::FS_FAT16 ;
+	fs .filesystem = specific_type ;
 		
 	// hack to disable silly mtools warnings
 	setenv( "MTOOLS_SKIP_CHECK", "1", 0 );
 
-	//find out if we can create fat16 file systems
-	if ( ! Glib::find_program_in_path( "mkdosfs" ) .empty() )
+	//find out if we can create fat file systems
+	if ( ! Glib::find_program_in_path( "mkfs.fat" ) .empty() )
+	{
 		fs .create = GParted::FS::EXTERNAL ;
-	
-	if ( ! Glib::find_program_in_path( "dosfsck" ) .empty() )
+		fs .create_with_label = GParted::FS::EXTERNAL ;
+		create_cmd = "mkfs.fat" ;
+	}
+	else if ( ! Glib::find_program_in_path( "mkdosfs" ) .empty() )
+	{
+		fs .create = GParted::FS::EXTERNAL ;
+		fs .create_with_label = GParted::FS::EXTERNAL ;
+		create_cmd = "mkdosfs" ;
+	}
+
+	if ( ! Glib::find_program_in_path( "fsck.fat" ) .empty() )
 	{
 		fs .check = GParted::FS::EXTERNAL ;
 		fs .read = GParted::FS::EXTERNAL ;
+		check_cmd = "fsck.fat" ;
+	}
+	else if ( ! Glib::find_program_in_path( "dosfsck" ) .empty() )
+	{
+		fs .check = GParted::FS::EXTERNAL ;
+		fs .read = GParted::FS::EXTERNAL ;
+		check_cmd = "dosfsck" ;
 	}
 
 	if ( ! Glib::find_program_in_path( "mdir" ) .empty() )
@@ -99,15 +116,22 @@ FS fat16::get_filesystem_support()
 	fs .copy = GParted::FS::GPARTED ;
 	fs .online_read = FS::GPARTED ;
 
-	fs .MIN = 16 * MEBIBYTE ;
-	fs .MAX = (4096 - 1) * MEBIBYTE ;  //Maximum seems to be just less than 4096 MiB
-	
+	if ( fs .filesystem == FS_FAT16 )
+	{
+		fs .MIN = 16 * MEBIBYTE ;
+		fs .MAX = (4096 - 1) * MEBIBYTE ;  //Maximum seems to be just less than 4096 MiB
+	}
+	else //FS_FAT32
+	{
+		fs .MIN = 33 * MEBIBYTE ; //Smaller file systems will cause windows scandisk to fail.
+	}
+
 	return fs ;
 }
 
 void fat16::set_used_sectors( Partition & partition ) 
 {
-	exit_status = Utils::execute_command( "dosfsck -n -v " + partition .get_path(), output, error, true ) ;
+	exit_status = Utils::execute_command( check_cmd + " -n -v " + partition .get_path(), output, error, true ) ;
 	if ( exit_status == 0 || exit_status == 1 || exit_status == 256 )
 	{
 		//total file system size in logical sectors
@@ -173,7 +197,7 @@ bool fat16::write_label( const Partition & partition, OperationDetail & operatio
 	if ( partition .get_label() .empty() )
 		cmd = "mlabel -c :: -i " + partition.get_path();
 	else
-		cmd = "mlabel ::\"" + partition.get_label() + "\" -i " + partition.get_path();
+		cmd = "mlabel ::\"" + pad_label( partition.get_label() ) + "\" -i " + partition.get_path();
 
 	operationdetail .add_child( OperationDetail( cmd, STATUS_NONE, FONT_BOLD_ITALIC ) ) ;
 
@@ -227,7 +251,8 @@ bool fat16::write_uuid( const Partition & partition, OperationDetail & operation
 
 bool fat16::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkdosfs -F16 -v -I -n \"" + new_partition .get_label() +
+	Glib::ustring fat_size = specific_type == FS_FAT16 ? "16" : "32" ;
+	return ! execute_command( create_cmd + " -F" + fat_size + " -v -I -n \"" + pad_label( new_partition .get_label() ) +
 				  "\" " + new_partition .get_path(),
 				  operationdetail,
 				  false,
@@ -236,12 +261,20 @@ bool fat16::create( const Partition & new_partition, OperationDetail & operation
 
 bool fat16::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
-	exit_status = execute_command( "dosfsck -a -w -v " + partition .get_path(), operationdetail,
+	exit_status = execute_command( check_cmd + " -a -w -v " + partition .get_path(), operationdetail,
 				       false, true );
 
 	return ( exit_status == 0 || exit_status == 1 || exit_status == 256 ) ;
 }
 
+//Private methods
+
+//Pad fat label with spaces to prevent mlabel writing corrupted labels.  See bug #700228
+const Glib::ustring fat16::pad_label( const Glib::ustring &label ) const
+{
+	Glib::ustring new_label = label ;
+	new_label .resize( Utils::get_filesystem_label_maxlength( specific_type ), ' ' ) ;
+	return new_label ;
+}
+
 } //GParted
-
-
