@@ -63,6 +63,10 @@ FS jfs::get_filesystem_support()
 	}
 
 	fs .online_read = FS::GPARTED ;
+#ifdef ENABLE_ONLINE_RESIZE
+	if ( Utils::kernel_version_at_least( 3, 6, 0 ) )
+		fs .online_grow = fs .grow ;
+#endif
 
 	fs .MIN = 16 * MEBIBYTE ;
 	
@@ -161,22 +165,29 @@ bool jfs::resize( const Partition & partition_new, OperationDetail & operationde
 {
 	bool success = true ;
 
-	Glib::ustring mount_point = mk_temp_dir( "", operationdetail ) ;
-	if ( mount_point .empty() )
-		return false ;
-
-	success &= ! execute_command( "mount -v -t jfs " + partition_new .get_path() + " " + mount_point,
-				      operationdetail, true ) ;
+	Glib::ustring mount_point ;
+	if ( ! partition_new .busy )
+	{
+		mount_point = mk_temp_dir( "", operationdetail ) ;
+		if ( mount_point .empty() )
+			return false ;
+		success &= ! execute_command( "mount -v -t jfs " + partition_new .get_path() + " " + mount_point,
+		                              operationdetail, true ) ;
+	}
+	else
+		mount_point = partition_new .get_mountpoint() ;
 
 	if ( success )
 	{
 		success &= ! execute_command( "mount -v -t jfs -o remount,resize " + partition_new .get_path() + " " + mount_point,
 					      operationdetail, true ) ;
 
-		success &= ! execute_command( "umount -v " + mount_point, operationdetail, true ) ;
+		if ( ! partition_new .busy )
+			success &= ! execute_command( "umount -v " + mount_point, operationdetail, true ) ;
 	}
 
-	rm_temp_dir( mount_point, operationdetail ) ;
+	if ( ! partition_new .busy )
+		rm_temp_dir( mount_point, operationdetail ) ;
 
 	return success ;
 }
