@@ -19,6 +19,8 @@
  
 #include "../include/linux_swap.h"
 
+#include <cerrno>
+
 namespace GParted
 {
 
@@ -43,6 +45,9 @@ FS linux_swap::get_filesystem_support()
 	FS fs ;
 	fs .filesystem = GParted::FS_LINUX_SWAP ;
 	
+	fs .read = FS::EXTERNAL ;
+	fs .online_read = FS::EXTERNAL ;
+
 	if ( ! Glib::find_program_in_path( "mkswap" ) .empty() )
 	{
 		fs .create = GParted::FS::EXTERNAL ;
@@ -65,6 +70,46 @@ FS linux_swap::get_filesystem_support()
 	return fs ;
 }
 
+void linux_swap::set_used_sectors( Partition & partition )
+{
+	if ( partition .busy )
+	{
+		T = -1 ; N = -1 ;
+		std::string line ;
+		std::ifstream input( "/proc/swaps" ) ;
+		if ( input )
+		{
+			Glib::ustring path = partition .get_path() ;
+			Glib::ustring::size_type path_len = path.length() ;
+			while ( getline( input, line ) )
+			{
+				if ( line .substr( 0, path_len ) == path )
+				{
+					sscanf( line .substr( path_len ) .c_str(), " %*s %Ld %Ld", &T, &N ) ;
+					break ;
+				}
+			}
+			input .close() ;
+		}
+		else
+		{
+			partition .messages .push_back( "open(\"/proc/swaps\", O_RDONLY): " + Glib::strerror( errno ) ) ;
+		}
+		if ( T > -1 && N > -1 )
+		{
+			T = Utils::round( T * ( KIBIBYTE / double(partition .sector_size) ) ) ;
+			N = Utils::round( N * ( KIBIBYTE / double(partition .sector_size) ) ) ;
+			partition .set_sector_usage( T, T - N ) ;
+		}
+	}
+	else
+	{
+		//By definition inactive swap space is 100% free
+		Sector size = partition .get_sector_length() ;
+		partition .set_sector_usage( size, size ) ;
+	}
+}
+
 void linux_swap::read_label( Partition & partition )
 {
 	if ( ! Utils::execute_command( "swaplabel " + partition .get_path(), output, error, true ) )
