@@ -85,7 +85,10 @@ FS ntfs::get_filesystem_support()
 	}
 
 	if ( ! Glib::find_program_in_path( "mkntfs" ) .empty() )
+	{
 		fs .create = GParted::FS::EXTERNAL ;
+		fs .create_with_label = GParted::FS::EXTERNAL ;
+	}
 
 	//resizing is a delicate process ...
 	if ( fs .read && fs .check )
@@ -105,6 +108,11 @@ FS ntfs::get_filesystem_support()
 
 	fs .online_read = FS::GPARTED ;
 
+	//Minimum NTFS partition size = (Minimum NTFS volume size) + (backup NTFS boot sector)
+	//                            = (1 MiB) + (1 sector)
+	// For GParted this means 2 MiB because smallest GUI unit is MiB.
+	fs. MIN = 2 * MEBIBYTE;
+
 	return fs ;
 }
 
@@ -193,26 +201,25 @@ bool ntfs::create( const Partition & new_partition, OperationDetail & operationd
 bool ntfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
 	bool return_value = false ;
-	Glib::ustring str_temp = "ntfsresize -P --force --force " + partition_new .get_path() ;
-	
+	Glib::ustring size = "" ;
 	if ( ! fill_partition )
 	{
-		str_temp += " -s " ;
-		str_temp += Utils::num_to_str( Utils::round( Utils::sector_to_unit(
-				partition_new .get_sector_length(), partition_new .sector_size, UNIT_BYTE ) ) -1 ) ;
+		size = " -s " + Utils::num_to_str( Utils::round( Utils::sector_to_unit(
+				partition_new .get_sector_length(), partition_new .sector_size, UNIT_BYTE ) ) ) ;
 	}
-	
+	Glib::ustring cmd = "ntfsresize --force --force" + size ;
+
 	//simulation..
 	operationdetail .add_child( OperationDetail( _("run simulation") ) ) ;
 
-	if ( ! execute_command( str_temp + " --no-action", operationdetail .get_last_child() ) )
+	if ( ! execute_command( cmd + " --no-action " + partition_new .get_path(), operationdetail .get_last_child() ) )
 	{
 		operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
 
 		//real resize
 		operationdetail .add_child( OperationDetail( _("real resize") ) ) ;
 
-		if ( ! execute_command( str_temp, operationdetail .get_last_child() ) )
+		if ( ! execute_command( cmd + " " + partition_new .get_path(), operationdetail .get_last_child() ) )
 		{
 			operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
 			return_value = true ;
@@ -242,7 +249,7 @@ bool ntfs::copy( const Partition & src_part,
 
 bool ntfs::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "ntfsresize -P -i -f -v " + partition .get_path(), operationdetail ) ; 
+	return ! execute_command( "ntfsresize -i -f -v " + partition .get_path(), operationdetail ) ;
 }
 
 } //GParted
