@@ -70,6 +70,10 @@ FS xfs::get_filesystem_support()
 		fs .move = GParted::FS::GPARTED ;
 
 	fs .online_read = FS::GPARTED ;
+#ifdef ENABLE_ONLINE_RESIZE
+	if ( Utils::kernel_version_at_least( 3, 6, 0 ) )
+		fs .online_grow = fs .grow ;
+#endif
 
 	fs .MIN = 32 * MEBIBYTE ;//official minsize = 16MB, but the smallest xfs_repair can handle is 32MB...
 	
@@ -178,21 +182,28 @@ bool xfs::resize( const Partition & partition_new, OperationDetail & operationde
 {
 	bool success = true ;
 
-	Glib::ustring mount_point = mk_temp_dir( "", operationdetail ) ;
-	if ( mount_point .empty() )
-		return false ;
-
-	success &= ! execute_command( "mount -v -t xfs " + partition_new .get_path() + " " + mount_point,
-				      operationdetail, true ) ;
+	Glib::ustring mount_point ;
+	if ( ! partition_new .busy )
+	{
+		mount_point = mk_temp_dir( "", operationdetail ) ;
+		if ( mount_point.empty() )
+			return false ;
+		success &= ! execute_command( "mount -v -t xfs " + partition_new .get_path() + " " + mount_point,
+		                              operationdetail, true ) ;
+	}
+	else
+		mount_point = partition_new .get_mountpoint() ;
 
 	if ( success )
 	{
 		success &= ! execute_command( "xfs_growfs " + mount_point, operationdetail, true ) ;
 
-		success &= ! execute_command( "umount -v " + mount_point, operationdetail, true ) ;
+		if ( ! partition_new .busy )
+			success &= ! execute_command( "umount -v " + mount_point, operationdetail, true ) ;
 	}
 
-	rm_temp_dir( mount_point, operationdetail ) ;
+	if ( ! partition_new .busy )
+		rm_temp_dir( mount_point, operationdetail ) ;
 
 	return success ;
 }
